<?php

namespace Drupal\prevnext\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Cache\Cache;

/**
 * Form for the module settings.
 *
 * @package Drupal\prevnext\Form
 */
class PrevNextSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'prevnext_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['prevnext.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('prevnext.settings');

    $form['prevnext_enabled_nodetypes'] = [
      '#title' => $this->t('Enabled Node Types'),
      '#description' => $this->t('Check node types enabled for PrevNext'),
      '#type' => 'checkboxes',
      '#options' => node_type_get_names(),
      '#default_value' => !empty($config->get('prevnext_enabled_nodetypes')) ? $config->get('prevnext_enabled_nodetypes') : [],
    ];

    $form['prevnext_premission_check'] = [
      '#title' => $this->t('Use permission check to view PrevNext links'),
      '#type' => 'checkbox',
      '#default_value' => !empty($config->get('prevnext_premission_check')) ? $config->get('prevnext_premission_check') : FALSE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save the config values.
    $this->config('prevnext.settings')
      ->set('prevnext_enabled_nodetypes', $form_state->getValue('prevnext_enabled_nodetypes'))
      ->set('prevnext_premission_check', (bool) $form_state->getValue('prevnext_premission_check'))
      ->save();

    Cache::invalidateTags(['entity_field_info']);
    parent::submitForm($form, $form_state);
  }

}
