<?php

namespace Drupal\prevnext;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\node\NodeInterface;

/**
 * Main service file.
 *
 * @package Drupal\prevnext
 */
class PrevNextService implements PrevNextServiceInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Previous / Next nids.
   *
   * @var array
   */
  public $prevnext;

  /**
   * PrevNextService constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager instance.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getPreviousNext(NodeInterface $node) {
    $nodes = $this->getNodesOfType($node);
    $current_nid = $node->id();

    $current_key = array_search($current_nid, $nodes);
    $this->prevnext['prev'] = ($current_key == 0) ? '' : $nodes[$current_key - 1];
    $this->prevnext['next'] = ($current_key == count($nodes) - 1) ? '' : $nodes[$current_key + 1];

    return $this->prevnext;
  }

  /**
   * Retrieves all nodes of the same type and language of given.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The node entity.
   *
   * @return array
   *   An array of nodes filtered by type, status and language.
   */
  protected function getNodesOfType(NodeInterface $node) {
    $query = $this->entityTypeManager->getStorage('node')->getQuery();
    $bundle = $node->bundle();
    $langcode = $node->language()->getId();
    $nodes = $query->condition('status', NodeInterface::PUBLISHED)
      ->condition('type', $bundle)
      ->condition('langcode', $langcode)
      ->addMetaData('type', $bundle)
      ->addMetaData('langcode', $langcode)
      ->addTag('prev_next_nodes_type')
      ->accessCheck(TRUE)
      ->execute();

    return array_values($nodes);
  }

}
